package fr.iut.pm.movieapplication.ui.viewmodel

import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.viewModelScope
import fr.iut.pm.movieapplication.network.dtos.MovieDTO
import fr.iut.pm.movieapplication.repository.MovieRepository
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

class MoviesVM(private val repository: MovieRepository) : ViewModel() {

    private val _popularMovies = MutableLiveData<List<MovieDTO>>()
    val popularMovies : MutableLiveData<List<MovieDTO>> = _popularMovies

    init {
         getPopularMovies()
    }


    private fun  getPopularMovies() {
        viewModelScope.launch {
            try {
                _popularMovies.value = repository.getPopularMovies()}
            catch (e : Exception) {
                e.stackTrace
            }

        }
    }

}

class MoviesVMFactory(
    private val repository: MovieRepository
    ) : ViewModelProvider.Factory {
    override fun <T : ViewModel> create(modelClass: Class<T>): T {
        if (modelClass.isAssignableFrom(MoviesVM::class.java)) {
            return MoviesVM(repository) as T
        }
        throw java.lang.IllegalArgumentException("Unknown ViewModel class")
    }

}